@@ -2150,6 +2150,20 @@ BOOL commands_mcp(int* rcode, vector_obj* argv, sWFd* nextout, sRFd* nextin, int
         return FALSE;
     }
 
+    BOOL preserve = FALSE;
+    int i;
+    const int len = vector_size(argv);
+    for(i=0; i<len; i++) {
+        char* arg = string_c_str(vector_item(argv, i));
+        if(strcmp(arg, "-p") == 0) {
+            preserve = TRUE;
+            string_delete(vector_item(argv, i));
+            vector_erase(argv, i);
+            i--;
+            continue;
+        }
+    }
+
     if(vector_size(argv) == 2) {
         gCopyOverride = kNone;
         gWriteProtected = kWPNone;
@@ -2220,7 +2234,7 @@ BOOL commands_mcp(int* rcode, vector_obj* argv, sWFd* nextout, sRFd* nextin, int
                     //draw_progress_box(mark_file_num);
                     mrefresh();
                     
-                    if(!file_copy(source, distination, false, false)) 
+                    if(!file_copy(source, distination, FALSE, preserve)) 
                     {
                         break;
                     }
@@ -2263,6 +2277,20 @@ BOOL commands_mbackup(int* rcode, vector_obj* argv, sWFd* nextout, sRFd* nextin,
         return FALSE;
     }
 
+    BOOL preserve = FALSE;
+    int i;
+    const int len = vector_size(argv);
+    for(i=0; i<len; i++) {
+        char* arg = string_c_str(vector_item(argv, i));
+        if(strcmp(arg, "-p") == 0) {
+            preserve = TRUE;
+            string_delete(vector_item(argv, i));
+            vector_erase(argv, i);
+            i--;
+            continue;
+        }
+    }
+
     if(vector_size(argv) == 2) {
         gCopyOverride = kNone;
         gWriteProtected = kWPNone;
@@ -2304,7 +2332,7 @@ BOOL commands_mbackup(int* rcode, vector_obj* argv, sWFd* nextout, sRFd* nextin,
                 //draw_progress_box(mark_file_num);
                 mrefresh();
                 
-                if(!file_copy(source, distination, false, false)) {
+                if(!file_copy(source, distination, FALSE, preserve)) {
                     return FALSE;
                 }
 
@@ -2327,8 +2355,8 @@ BOOL commands_mmv(int* rcode, vector_obj* argv, sWFd* nextout, sRFd* nextin, int
         return FALSE;
     }
 
-
     BOOL force = FALSE;
+    BOOL preserve = FALSE;
     int j=0;
     for(j=1; j<vector_size(argv); j++) {
         char* item = string_c_str(vector_item(argv, j));
@@ -2340,6 +2368,13 @@ BOOL commands_mmv(int* rcode, vector_obj* argv, sWFd* nextout, sRFd* nextin, int
             j--;
             continue;
         }
+        else if(strcmp(item, "-p") == 0) {
+            preserve = TRUE;
+            string_delete(vector_item(argv, j));
+            vector_erase(argv, j);
+            j--;
+            continue;
+        }
     }
 
     if(vector_size(argv) == 2) {
@@ -2418,7 +2453,7 @@ BOOL commands_mmv(int* rcode, vector_obj* argv, sWFd* nextout, sRFd* nextin, int
                     //draw_progress_box(mark_file_num);
                     mrefresh();
                     
-                    if(!file_copy(source, distination, true, false)) {
+                    if(!file_copy(source, distination, TRUE, preserve)) {
                         break;
                     }
 
@@ -2486,7 +2521,7 @@ BOOL commands_mrm(int* rcode, vector_obj* argv, sWFd* nextout, sRFd* nextin, int
                     //draw_progress_box(mark_file_num);
                     mrefresh();
                     
-                    if(!file_remove(source, false, true)) {
+                    if(!file_remove(source, FALSE, TRUE)) {
                         break;
                     }
 
@@ -2522,6 +2557,7 @@ BOOL commands_mtrashbox(int* rcode, vector_obj* argv, sWFd* nextout, sRFd* nexti
     }
 
     BOOL force = FALSE;
+    BOOL preserve = FALSE;
     int j=0;
     for(j=1; j<vector_size(argv); j++) {
         char* item = string_c_str(vector_item(argv, j));
@@ -2533,6 +2569,13 @@ BOOL commands_mtrashbox(int* rcode, vector_obj* argv, sWFd* nextout, sRFd* nexti
             j--;
             continue;
         }
+        else if(strcmp(item, "-p") == 0) {
+            preserve = TRUE;
+            string_delete(vector_item(argv, j));
+            vector_erase(argv, j);
+            j--;
+            continue;
+        }
     }
 
     if(vector_size(argv) == 1) {
@@ -2618,7 +2661,7 @@ BOOL commands_mtrashbox(int* rcode, vector_obj* argv, sWFd* nextout, sRFd* nexti
                     //draw_progress_box(mark_file_num);
                     mrefresh();
                     
-                    if(!file_copy(source, distination, true, false)) {
+                    if(!file_copy(source, distination, TRUE, preserve)) {
                         break;
                     }
 
